@@ -30,6 +30,7 @@ from .resnet.resnet import ResNet
 from .resnet.torchvision_resnet import build_torchvision_resnet
 from .resnet.official_resnest import build_official_resnest
 from .resnet.resnet3d import ResNet3D
+from .ghostnet.ghostnet import GhostNet
 
 logger = logging.get_logger(__name__)
 
@@ -58,6 +59,6 @@ def build_recognizer(cfg, device):
 
     model = model.to(device=device)
     if du.get_world_size() > 1:
-        model = DDP(model, device_ids=[device], output_device=device, find_unused_parameters=True)
+        model = DDP(model, device_ids=[device], output_device=device, find_unused_parameters=False)
 
     return model
